# How to Contribute
1. Read and complete the [Contributor License Agreement](https://github.com/tagged/brocade-tool/blob/master/CLA.txt).
1. When complete, email a PDF of the signed agreement to [legal@ifwe.co](mailto:legal@ifwe.co).
1. Once you have received a confirmation that your signed CLA was received, contribute your code, documentation, or any other materials with a pull request.

## Coding Style
* PEP8
* Indents are 4 whitespaces
